@@ -5,9 +5,9 @@
  *
  * Prints the page header (duh)
  *
- * @copyright 1999-2017 The SquirrelMail Project Team
+ * @copyright 1999-2019 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: page_header.php 14642 2017-01-27 20:31:33Z pdontthink $
+ * @version $Id: page_header.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  */
 
@@ -62,7 +62,7 @@ function displayHtmlHeader($title='SquirrelMail', $xtra_param='', $do_hook=TRUE,
     if ( !sqgetGlobalVar('base_uri', $base_uri, SQ_SESSION) ) {
         global $base_uri;
     }
-    global $theme_css, $custom_css, $pageheader_sent, $browser_rendering_mode;
+    global $theme_css, $custom_css, $pageheader_sent, $browser_rendering_mode, $head_tag_extra;
 
     // prevent clickjack attempts
 // FIXME: should we use DENY instead?  We can also make this a configurable value, including giving the admin the option of removing this entirely in case they WANT to be framed by an external domain
@@ -75,7 +75,18 @@ function displayHtmlHeader($title='SquirrelMail', $xtra_param='', $do_hook=TRUE,
          : /* "quirks" */ '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">')) .
          "\n\n" . html_tag( 'html' ,'' , '', '', '' ) . "\n<head>\n" .
          "<meta name=\"robots\" content=\"noindex,nofollow\">\n" .
-         "<meta http-equiv=\"x-dns-prefetch-control\" content=\"off\">\n";
+         "<meta http-equiv=\"x-dns-prefetch-control\" content=\"off\">\n"
+
+    // For adding a favicon or anything else that should be inserted in *ALL* <head> for *ALL* documents,
+    // define $head_tag_extra in config/config_local.php
+    // The string "###SM BASEURI###" will be replaced with the base URI for this SquirrelMail installation.
+    // When not defined, a default is provided that displays the default favicon.ico.
+    // If you override this and still want to use the default favicon.ico, you'll have to include the following
+    // following in your $head_tag_extra string:
+    // $head_tag_extra = '<link rel="shortcut icon" href="###SM BASEURI###favicon.ico" />...<YOUR CONTENT HERE>...';
+    //
+       . (empty($head_tag_extra) ? '<link rel="shortcut icon" href="' . sqm_baseuri() . 'favicon.ico" />'
+       : str_replace('###SM BASEURI###', sqm_baseuri(), $head_tag_extra))
 
     // prevent clickjack attempts using JavaScript for browsers that
     // don't support the X-Frame-Options header...
@@ -84,7 +95,7 @@ function displayHtmlHeader($title='SquirrelMail', $xtra_param='', $do_hook=TRUE,
     // if not, log out immediately -- this is an attempt to do the same
     // thing that the X-Frame-Options does using JavaScript (never a good
     // idea to rely on JavaScript-based solutions, though)
-    echo '<script type="text/javascript" language="JavaScript">'
+       . '<script type="text/javascript" language="JavaScript">'
        . "\n<!--\n"
        . 'if (self != top) { try { if (document.domain != top.document.domain) {'
        . ' throw "Clickjacking security violation! Please log out immediately!"; /* this code should never execute - exception should already have been thrown since it\'s a security violation in this case to even try to access top.document.domain (but it\'s left here just to be extra safe) */ } } catch (e) { self.location = "'
@@ -244,13 +255,20 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
             else
                 $js .= "    var f = document.forms.length;\n".
                 "    var i = 0;\n".
+                "    var remembered_form = -1;\n".
                 "    var pos = -1;\n".
+                "    var remembered_pos = -1;\n".
                 "    while( pos == -1 && i < f ) {\n".
                 "        var e = document.forms[i].elements.length;\n".
                 "        var j = 0;\n".
                 "        while( pos == -1 && j < e ) {\n".
                 "            if ( document.forms[i].elements[j].type == 'text' ) {\n".
-                "                pos = j;\n".
+                "                if ( document.forms[i].elements[j].id.substring(0, 13) == '__lastfocus__' ) {\n".
+                "                    remembered_pos = j;\n".
+                "                    remembered_form = i;\n".
+                "                } else if ( document.forms[i].elements[j].id.substring(0, 11) != '__nofocus__' ) {\n".
+                "                    pos = j;\n".
+                "                }\n".
                 "            }\n".
                 "            j++;\n".
                 "        }\n".
@@ -258,6 +276,8 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
                 "    }\n".
                 "    if( pos >= 0 ) {\n".
                 "        document.forms[i-1].elements[pos].focus();\n".
+                "    } else if ( remembered_pos >= 0 ) {\n".
+                "        document.forms[remembered_form].elements[remembered_pos].focus();\n".
                 "    }\n".
                 "}\n";
 
@@ -273,21 +293,30 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
              "function checkForm() {\n".
              "   var f = document.forms.length;\n".
              "   var i = 0;\n".
+             "   var remembered_form = -1;\n".
              "   var pos = -1;\n".
+             "   var remembered_pos = -1;\n".
              "   while( pos == -1 && i < f ) {\n".
              "       var e = document.forms[i].elements.length;\n".
              "       var j = 0;\n".
              "       while( pos == -1 && j < e ) {\n".
              "           if ( document.forms[i].elements[j].type == 'text' " .
-             "           || document.forms[i].elements[j].type == 'password' ) {\n".
-             "               pos = j;\n".
+             "            || document.forms[i].elements[j].type == 'password' ) {\n".
+             "               if ( document.forms[i].elements[j].id.substring(0, 13) == '__lastfocus__' ) {\n".
+             "                   remembered_pos = j;\n".
+             "                   remembered_form = i;\n".
+             "               } else if ( document.forms[i].elements[j].id.substring(0, 11) != '__nofocus__' ) {\n".
+             "                   pos = j;\n".
+             "               }\n".
              "           }\n".
              "           j++;\n".
              "       }\n".
-             "   i++;\n".
+             "       i++;\n".
              "   }\n".
              "   if( pos >= 0 ) {\n".
              "       document.forms[i-1].elements[pos].focus();\n".
+             "   } else if ( remembered_pos >= 0 ) {\n".
+             "       document.forms[remembered_form].elements[remembered_pos].focus();\n".
              "   }\n".
              "   $xtra\n".
              "}\n";
@@ -357,7 +386,7 @@ function displayPageHeader($color, $mailbox, $xtra='', $session=false) {
     echo "&nbsp;&nbsp;\n";
     displayInternalLink ('src/options.php', _("Options"));
     echo "&nbsp;&nbsp;\n";
-    displayInternalLink ("src/search.php?mailbox=$urlMailbox", _("Search"));
+    displayInternalLink ("src/search.php?mailbox=$urlMailbox&amp;what=", _("Search"));
     echo "&nbsp;&nbsp;\n";
     displayInternalLink ('src/help.php', _("Help"));
     echo "&nbsp;&nbsp;\n";
@@ -421,13 +450,20 @@ function compose_Header($color, $mailbox) {
             else
                 $js .= "var f = document.forms.length;\n".
                 "var i = 0;\n".
+                "var remembered_form = -1;\n".
                 "var pos = -1;\n".
+                "var remembered_pos = -1;\n".
                 "while( pos == -1 && i < f ) {\n".
                     "var e = document.forms[i].elements.length;\n".
                     "var j = 0;\n".
                     "while( pos == -1 && j < e ) {\n".
                         "if ( document.forms[i].elements[j].type == 'text' ) {\n".
-                            "pos = j;\n".
+                            "if ( document.forms[i].elements[j].id.substring(0, 13) == '__lastfocus__' ) {\n".
+                                "remembered_pos = j;\n".
+                                "remembered_form = i;\n".
+                            "} else if ( document.forms[i].elements[j].id.substring(0, 11) != '__nofocus__' ) {\n".
+                                "pos = j;\n".
+                            "}\n".
                         "}\n".
                         "j++;\n".
                     "}\n".
@@ -435,6 +471,8 @@ function compose_Header($color, $mailbox) {
                 "}\n".
                 "if( pos >= 0 ) {\n".
                     "document.forms[i-1].elements[pos].focus();\n".
+                "} else if ( remembered_pos >= 0 ) {\n".
+                    "document.forms[remembered_form].elements[remembered_pos].focus();\n".
                 "}\n".
             "}\n";
         $js .= "// -->\n".
