@@ -7,10 +7,10 @@
  *   deletes or moves currently displayed message and displays
  *   next or previous message.
  *
- * Copyright (c) 1999-2018 The SquirrelMail Project Team
+ * Copyright (c) 1999-2019 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: setup.php 14749 2018-01-16 23:36:07Z pdontthink $
+ * $Id: setup.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package plugins
  * @subpackage delete_move_next
  */
@@ -204,9 +204,9 @@ function delete_move_next_read($currloc) {
                  "<td bgcolor=\"$color[9]\" width=\"100%\" align=\"center\"><small>";
 
         if ($prev > 0){
-            echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Delete &amp; Prev") . "</a>" . "&nbsp;|&nbsp;";
+            echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;delete_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Delete &amp; Prev") . "</a>" . "&nbsp;|&nbsp;";
             if ($delete_move_next_show_unread == SMPREF_ON) {
-                echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;unread_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Unread &amp; Prev") . "</a>" . "&nbsp;|&nbsp;";
+                echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$prev_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;unread_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Unread &amp; Prev") . "</a>" . "&nbsp;|&nbsp;";
             }
         }
         else {
@@ -217,9 +217,9 @@ function delete_move_next_read($currloc) {
         }
         if ($next > 0){
             if ($delete_move_next_show_unread == SMPREF_ON) {
-                echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;unread_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Unread &amp; Next") . "</a>&nbsp;|&nbsp;";
+                echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;unread_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Unread &amp; Next") . "</a>&nbsp;|&nbsp;";
             }
-            echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;show_more=0&amp;delete_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Delete &amp; Next") . "</a>";
+            echo "<a href=\"" . $base_uri . "src/read_body.php?passed_id=$next_if_del&amp;mailbox=$urlMailbox&amp;sort=$sort&amp;startMessage=$startMessage&amp;delete_id=$passed_id&amp;smtoken=" . sm_generate_security_token() . "\">" . _("Delete &amp; Next") . "</a>";
         } else {
             if ($delete_move_next_show_unread == SMPREF_ON) {
                 echo _("Unread &amp; Next") . "&nbsp;|&nbsp;";
@@ -279,7 +279,7 @@ function delete_move_next_moveNextForm($next) {
             ' <select name="targetMailbox">';
     get_move_target_list(); 
     echo    '</select> '.
-            '<input type="submit" value="' . _("Move") . '">'.
+            '<input type="submit" id="moveBtn" value="' . _("Move") . '">'.
             '</small>'.
            '</form>'.
          '</td>'.
@@ -303,7 +303,7 @@ function delete_move_next_moveRightMainForm() {
             ' <select name="targetMailbox">';
     get_move_target_list(); 
     echo    ' </select> ' .
-            '<input type=submit value="' . _("Move") . '">'.
+            '<input type=submit id="moveBtn" value="' . _("Move") . '">'.
             '</small>'.
          '</form>' .
          '</td>'.
