@@ -5,9 +5,9 @@
  *
  * Enables message moving between folders on the IMAP server.
  *
- * @copyright 1999-2018 The SquirrelMail Project Team
+ * @copyright 1999-2019 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: move_messages.php 14749 2018-01-16 23:36:07Z pdontthink $
+ * @version $Id: move_messages.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  */
 
@@ -33,13 +33,7 @@ if ( !sqgetGlobalVar('composesession', $composesession, SQ_SESSION) ) {
 function attachSelectedMessages($msg, $imapConnection) {
     global $username, $attachment_dir, $startMessage,
            $data_dir, $composesession, $uid_support, $mailbox,
-       $msgs, $thread_sort_messages, $allow_server_sort, $show_num,
-       $compose_messages;
-
-    if (!isset($compose_messages)) {
-        $compose_messages = array();
-            sqsession_register($compose_messages,'compose_messages');
-    }
+       $msgs, $thread_sort_messages, $allow_server_sort, $show_num;
 
     if (!$composesession) {
         $composesession = 1;
@@ -118,6 +112,12 @@ function attachSelectedMessages($msg, $imapConnection) {
         }
         $i++;
     }
+
+    sqgetGlobalVar('compose_messages', $compose_messages, SQ_SESSION);
+    if (!isset($compose_messages)
+     || !is_array($compose_messages)) {
+        $compose_messages = array();
+    }
     $compose_messages[$composesession] = $composeMessage;
     sqsession_register($compose_messages,'compose_messages');
     session_write_close();
