@@ -5,9 +5,9 @@
  *
  * Display Identities Options
  *
- * @copyright 1999-2017 The SquirrelMail Project Team
+ * @copyright 1999-2019 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options_identities.php 14700 2017-07-06 02:46:14Z pdontthink $
+ * @version $Id: options_identities.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  * @subpackage prefs
  * @since 1.1.3
@@ -30,15 +30,17 @@ include_once(SM_PATH . 'functions/html.php');
 include_once(SM_PATH . 'functions/forms.php');
 include_once(SM_PATH . 'functions/identity.php');
 
+if (!sqgetGlobalVar('identities', $identities, SQ_SESSION)) {
+    $identities = get_identities();
+}
+
 /* make sure that page is not available when $edit_identity is false */
-if (!$edit_identity) {
+$cnt = count($identities);
+if ($cnt < 2 && !$edit_identity) {
     error_box(_("Editing identities is disabled."),$color);
     die('</body></html>');
 }
 
-if (!sqgetGlobalVar('identities', $identities, SQ_SESSION)) {
-    $identities = get_identities();
-}
 sqgetGlobalVar('newidentities', $newidentities, SQ_POST);
 sqgetGlobalVar('smaction', $smaction, SQ_POST);
 sqgetGlobalVar('return', $return, SQ_POST);
@@ -69,6 +71,8 @@ if (!empty($smaction) && is_array($smaction)) {
 
     $identities = sqfixidentities( $newidentities , $identid , $action );
     save_identities($identities);
+    // save_identities() can also alter the identities, so:
+    $identities = get_identities();
 }
 
 if (!empty($return)) {
@@ -82,8 +86,8 @@ do_hook('options_identities_top');
 
 $td_str = '<form name="f" action="options_identities.php" method="post"><br />' . "\n"
         . addHidden('smtoken', sm_generate_security_token()) . "\n"
-        . '<table border="0" cellspacing="0" cellpadding="0" width="100%">' . "\n";
-$cnt = count($identities);
+        . '<table border="0" cellspacing="0" cellpadding="2" width="100%">' . "\n";
+$cnt = count($identities); // $identities may have changed, so we need to count again
 foreach( $identities as $iKey=>$ident ) {
 
     if ($iKey == 0) {
@@ -96,7 +100,8 @@ foreach( $identities as $iKey=>$ident ) {
 
 }
 
-$td_str .= ShowIdentityInfo( _("Add a New Identity"), array('full_name'=>'','email_address'=>'','reply_to'=>'','signature'=>''), $cnt);
+if ($edit_identity)
+    $td_str .= ShowIdentityInfo( _("Add a New Identity"), array('full_name'=>'','email_address'=>'','reply_to'=>'','signature'=>''), $cnt);
 $td_str .= '</table>' . "\n";
 $td_str .= '</form>';
 
@@ -121,7 +126,7 @@ echo '<br /> ' . "\n" .
 
 
 function ShowIdentityInfo($title, $identity, $id ) {
-    global $color;
+    global $color, $edit_identity, $edit_name, $edit_reply_to, $cnt;
 
     if (empty($identity['full_name']) && empty($identity['email_address']) && empty($identity['reply_to']) && empty($identity['signature'])) {
         $bg = '';
@@ -139,9 +144,11 @@ function ShowIdentityInfo($title, $identity, $id ) {
     $return_str .= '<tr>' . "\n";
     $return_str .= '  <th style="text-align:center;background-color:' . $color[9] . ';" colspan="2">' . $title . '</th> '. "\n";
     $return_str .= '</tr>' . "\n";
-    $return_str .= sti_input( _("Full Name") , sprintf($name, $id, 'full_name'), $identity['full_name'], $bg);
-    $return_str .= sti_input( _("E-Mail Address") , sprintf($name, $id, 'email_address'), $identity['email_address'], $bg);
-    $return_str .= sti_input( _("Reply To"), sprintf($name, $id, 'reply_to'), $identity['reply_to'], $bg);
+    $return_str .= sti_input( _("Full Name") , sprintf($name, $id, 'full_name'), $identity['full_name'], $bg, ($edit_identity || ($cnt > 1 && $edit_name)));
+    $return_str .= sti_input( _("E-Mail Address") , sprintf($name, $id, 'email_address'), $identity['email_address'], $bg, $edit_identity);
+    // don't show reply-to AT ALL if it's not editable
+    if ($edit_identity || ($cnt > 1 && $edit_reply_to))
+        $return_str .= sti_input( _("Reply To"), sprintf($name, $id, 'reply_to'), $identity['reply_to'], $bg, ($edit_identity || ($cnt > 1 && $edit_reply_to)));
     $return_str .= sti_textarea( _("Signature"), sprintf($name, $id, 'signature'), $identity['signature'], $bg);
     $return_str .= concat_hook_function('options_identities_table', array($bg, $empty, $id));
     $return_str .= '<tr' . $bg . '> ' . "\n";
@@ -151,7 +158,8 @@ function ShowIdentityInfo($title, $identity, $id ) {
 
     if (!$empty && $id > 0) {
         $return_str .= '    <input type="submit" name="smaction[makedefault][' . $id . ']" value="' . _("Make Default") . '" />' . "\n";
-        $return_str .= '    <input type="submit" name="smaction[delete]['.$id.']" value="' . _("Delete") . '" />' . "\n";
+        if ($edit_identity)
+            $return_str .= '    <input type="submit" name="smaction[delete]['.$id.']" value="' . _("Delete") . '" />' . "\n";
 
         if ($id > 1) {
             $return_str .= '    <input type="submit" name="smaction[move]['.$id.']" value="' . _("Move Up") . '" />' . "\n";
@@ -170,11 +178,14 @@ function ShowIdentityInfo($title, $identity, $id ) {
 
 }
 
-function sti_input( $title, $name, $data, $bgcolor ) {
+function sti_input( $title, $name, $data, $bgcolor, $can_edit ) {
     $str = '';
     $str .= '<tr' . $bgcolor . ">\n";
-    $str .= '  <td style="white-space: nowrap;text-align:right;">' . $title . ' </td>' . "\n";
-    $str .= '  <td> <input type="text" name="' . $name . '" size="50" value="'. sm_encode_html_special_chars($data) . '"> </td>' . "\n";
+    $str .= '  <td style="white-space: nowrap;text-align:right;">' . $title . ': </td>' . "\n";
+    if ($can_edit)
+        $str .= '  <td> <input type="text" name="' . $name . '" size="50" value="'. sm_encode_html_special_chars($data) . '"> </td>' . "\n";
+    else
+        $str .= '  <td>&nbsp;' . sm_encode_html_special_chars($data) . ' </td>' . "\n";
     $str .= '</tr>';
 
     return $str;
@@ -184,7 +195,7 @@ function sti_input( $title, $name, $data, $bgcolor ) {
 function sti_textarea( $title, $name, $data, $bgcolor ) {
     $str = '';
     $str .= '<tr' . $bgcolor . ">\n";
-    $str .= '  <td style="white-space: nowrap;text-align:right;">' . $title . ' </td>' . "\n";
+    $str .= '  <td style="white-space: nowrap;text-align:right;">' . $title . ': </td>' . "\n";
     $str .= '  <td> <textarea name="' . $name . '" cols="50" rows="5">'. "\n" . sm_encode_html_special_chars($data) . '</textarea> </td>' . "\n";
     $str .= '</tr>';
 
