@@ -5,9 +5,9 @@
  *
  * This is the code to view the message header.
  *
- * @copyright 1999-2017 The SquirrelMail Project Team
+ * @copyright 1999-2019 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: view_header.php 14642 2017-01-27 20:31:33Z pdontthink $
+ * @version $Id: view_header.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  */
 
@@ -27,7 +27,21 @@ require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/html.php');
 require_once(SM_PATH . 'functions/url_parser.php');
 
-function parse_viewheader($imapConnection,$id, $passed_ent_id) {
+/**
+  * Extract message headers
+  *
+  * @param resource $imapConnection
+  * @param string $id Message ID
+  * @param string $passed_ent_id Nested/attached/embedded message ID (if any)
+  *
+  * @return array List of all message headers, where each
+  *               element is a sub-array that contains two
+  *               elements: header name and header value
+  *               (in that order) where the header value is
+  *               HTML-formatted, ready for display in browser
+  *
+  */
+function parse_viewheader($imapConnection, $id, $passed_ent_id) {
     global $uid_support;
 
     $header_full = array();
@@ -115,6 +129,7 @@ function view_header($header, $mailbox, $color) {
             '</td></tr></table>'."\n" 
          )
     );
+    do_hook('view_header_bottom');
     echo '</body></html>';
 }
 
