@@ -7,12 +7,15 @@
  * A SINGLE FREAKING COMMENT IN! Whoever is responsible for this,
  * be very ashamed.
  *
- * @copyright 1999-2017 The SquirrelMail Project Team
+ * @copyright 1999-2019 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: view_text.php 14673 2017-06-11 22:38:13Z pdontthink $
+ * @version $Id: view_text.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  */
 
+/** This is the view_text page */
+define('PAGE_NAME', 'view_text');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
