@@ -7,9 +7,9 @@
  * shown can be given as parameters. If the user is not logged in
  * this file will verify username and password.
  *
- * @copyright 1999-2017 The SquirrelMail Project Team
+ * @copyright 1999-2019 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: webmail.php 14642 2017-01-27 20:31:33Z pdontthink $
+ * @version $Id: webmail.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  */
 
@@ -68,14 +68,45 @@ if ($my_language != $squirrelmail_language) {
 
 set_up_language($my_language);
 
-global $browser_rendering_mode;
+// prevent clickjack attempts
+// FIXME: should we use DENY instead?  We can also make this a configurable value, including giving the admin the option of removing this entirely in case they WANT to be framed by an external domain
+header('X-Frame-Options: SAMEORIGIN');
+
+global $browser_rendering_mode, $head_tag_extra;
 $output = ($browser_rendering_mode === 'standards' || $browser_rendering_mode === 'almost'
        ? '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">'
        : /* "quirks" */ '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN">').
-          "\n<html><head>\n" .
-          "<meta name=\"robots\" content=\"noindex,nofollow\">\n" .
-          "<title>$org_title</title>\n".
-          "</head>";
+          "\n<html><head>\n"
+
+          // For adding a favicon or anything else that should be inserted in *ALL* <head> for *ALL* documents,
+          // define $head_tag_extra in config/config_local.php
+          // The string "###SM BASEURI###" will be replaced with the base URI for this SquirrelMail installation.
+          // When not defined, a default is provided that displays the default favicon.ico.
+          // If you override this and still want to use the default favicon.ico, you'll have to include the following
+          // following in your $head_tag_extra string:
+          // $head_tag_extra = '<link rel="shortcut icon" href="###SM BASEURI###favicon.ico" />...<YOUR CONTENT HERE>...';
+          //
+          . (empty($head_tag_extra) ? '<link rel="shortcut icon" href="' . sqm_baseuri() . 'favicon.ico" />'
+          : str_replace('###SM BASEURI###', sqm_baseuri(), $head_tag_extra))
+
+          // prevent clickjack attempts using JavaScript for browsers that
+          // don't support the X-Frame-Options header...
+          // we check to see if we are *not* the top page, and if not, check
+          // whether or not the top page is in the same domain as we are...
+          // if not, log out immediately -- this is an attempt to do the same
+          // thing that the X-Frame-Options does using JavaScript (never a good
+          // idea to rely on JavaScript-based solutions, though)
+          . '<script type="text/javascript" language="JavaScript">'
+          . "\n<!--\n"
+          . 'if (self != top) { try { if (document.domain != top.document.domain) {'
+          . ' throw "Clickjacking security violation! Please log out immediately!"; /* this code should never execute - exception should already have been thrown since it\'s a security violation in this case to even try to access top.document.domain (but it\'s left here just to be extra safe) */ } } catch (e) { self.location = "'
+          . sqm_baseuri() . 'src/signout.php"; top.location = "'
+          . sqm_baseuri() . 'src/signout.php" } }'
+          . "\n// -->\n</script>\n"
+
+          . "<meta name=\"robots\" content=\"noindex,nofollow\">\n"
+          . "<title>$org_title</title>\n"
+          . "</head>";
 
 $left_size = getPref($data_dir, $username, 'left_size');
 $location_of_bar = getPref($data_dir, $username, 'location_of_bar');
